@@ -21,6 +21,12 @@ public:
     void load();
 
 signals:
+    void closed();
+    void landscape();
+
+public slots:
+    void sendClosed();
+
 
 private:
     XML *xml;
