@@ -1,5 +1,6 @@
 #include "weightdialog.h"
 #include <QDebug>
+#include <QMaemo5InformationBox>
 
 WeightDialog::WeightDialog(QWidget *parent) :
         QDialog(parent)
@@ -116,14 +117,28 @@ void WeightDialog::save()
     else if(radioHard->isChecked())
         status = "hard";
     else
+    {
+        QMaemo5InformationBox::information(this, "You must select status.", QMaemo5InformationBox::DefaultTimeout);
         return;
+    }
 
     qDebug () << "WeightDialog::save 2";
 
-    if(btnReps->valueText() == "")
+    if(btnReps->valueText() == "" && group != "Cardio")
+    {
+        QMaemo5InformationBox::information(this, "You must select reps.", QMaemo5InformationBox::DefaultTimeout);
         return;
-    else if(btnVar->valueText() == "")
+    }
+    else if(btnVar->valueText() == "" && group != "Cardio")
+    {
+        QMaemo5InformationBox::information(this, "You must select weight.", QMaemo5InformationBox::DefaultTimeout);
         return;
+    }
+    else if(btnVar->valueText() == "" && group == "Cardio")
+    {
+        QMaemo5InformationBox::information(this, "You must select distance.", QMaemo5InformationBox::DefaultTimeout);
+        return;
+    }
 
     qDebug () << "WeightDialog::save 3";
     weight = btnVar->valueText();
