@@ -22,9 +22,9 @@ public:
     void saveProgram(QString name, QModelIndexList exercises);
     QList <QString> loadProgram(QString name);
     QList <QString> getPrograms();
+    void removeProgram(QString name);
 
-
-    void removeElement(QString name);
+    void removeElement(QString name, QString filename);
 
     void saveCardio(QString name);
     void updateLastDistance(QString name, QString distance, QString min, QString sec, QString status);
@@ -44,6 +44,7 @@ public:
     QList <int> getTodaysCalories();
     void getMeanCalories();
     QList <int> getCaloriesByName(QString name);
+    void removeIngredient(QString name);
 
     void import(QString filename);
     void exportExercises(QModelIndexList name);
